netapp_ontap.models.cluster_active_directory API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_active_directory`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterActiveDirectorySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterActiveDirectory object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `force_account_overwrite: bool POST PATCH`

    If set to true and a machine account exists with the same name as specified in "name" in Active Directory, it is overwritten and reused.

    Example: false

  `fqdn: str GET POST PATCH`

    Fully qualified domain name.

    Example: server1.com

  `name: str GET POST PATCH`

    Active Directory account NetBIOS name.

    Example: account1

  `organizational_unit: str GET POST PATCH`

    Organizational unit under which the Active Directory account is created.

    Example: CN=Test

  `password: str POST PATCH`

    Administrator password required for Active Directory account creation, modification, and deletion.

    Example: testpwd

  `security: ActiveDirectorySecurity GET POST PATCH`

    The security field of the cluster_active_directory.

  `username: str POST PATCH`

    Administrator username required for Active Directory account creation, modification, and deletion.

    Example: admin